==> trilinos_9.0.3.dfsg.orig.tar.gz: trilinos-9.0.3.dfsg.orig/packages/Sundance/src-std-framework/Assembly/SundanceTrivialGrouper.hpp <==
/* @HEADER@ */
// ************************************************************************
// 
//                              Sundance
//                 Copyright (2005) Sandia Corporation
// 
// Copyright (year first published) Sandia Corporation.  Under the terms 
// of Contract DE-AC04-94AL85000 with Sandia Corporation, the U.S. Government 
// retains certain rights in this software.
// 
// This library is free software; you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as
// published by the Free Software Foundation; either version 2.1 of the
// License, or (at your option) any later version.
//  
// This library is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//                                                                                 
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
// USA                                                                                
// Questions? Contact Kevin Long (krlong@sandia.gov), 
// Sandia National Laboratories, Livermore, California, USA
// 
// ************************************************************************
/* @HEADER@ */

#ifndef SUNDANCE_TRIVIALGROUPER_H
#define SUNDANCE_TRIVIALGROUPER_H

#include "SundanceDefs.hpp"
#include "SundanceGrouperBase.hpp"

#ifndef DOXYGEN_DEVELOPER_ONLY

namespace SundanceStdFwk
{
  using namespace SundanceUtils;
  using namespace SundanceStdMesh;
  using namespace SundanceStdMesh::Internal;
  using namespace SundanceCore;
  using namespace SundanceCore::Internal;

  namespace Internal
  {
    using namespace Teuchos;

    /** 
     * Grouper
     */
    class TrivialGrouper : public GrouperBase
    {
    public:
      /** */
      TrivialGrouper() : GrouperBase() {;}
      /** */
      TrivialGrouper(const ParameterList& verbParams) : GrouperBase(verbParams) {;}

      /** */
      virtual ~TrivialGrouper(){;}

      /** */
      virtual void findGroups(const EquationSet& eqn,
                              const CellType& maxCellType,
                              int spatialDim,
                              const CellType& cellType,
                              int cellDim,
                              const QuadratureFamily& quad,
                              const RefCountPtr<SparsitySuperset>& sparsity,
                              Array<IntegralGroup>& groups) const ;
                              
    };

  }
}

#endif  /* DOXYGEN_DEVELOPER_ONLY */

#endif

==> trilinos_10.0.4.dfsg.orig.tar.gz: trilinos-10.0.4.dfsg.orig/packages/Sundance/src-std-framework/Assembly/SundanceTrivialGrouper.hpp <==
/* @HEADER@ */
// ************************************************************************
// 
//                              Sundance
//                 Copyright (2005) Sandia Corporation
// 
// Copyright (year first published) Sandia Corporation.  Under the terms 
// of Contract DE-AC04-94AL85000 with Sandia Corporation, the U.S. Government 
// retains certain rights in this software.
// 
// This library is free software; you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as
// published by the Free Software Foundation; either version 2.1 of the
// License, or (at your option) any later version.
//  
// This library is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//                                                                                 
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
// USA                                                                                
// Questions? Contact Kevin Long (krlong@sandia.gov), 
// Sandia National Laboratories, Livermore, California, USA
// 
// ************************************************************************
/* @HEADER@ */

#ifndef SUNDANCE_TRIVIALGROUPER_H
#define SUNDANCE_TRIVIALGROUPER_H

#include "SundanceDefs.hpp"
#include "SundanceGrouperBase.hpp"

namespace SundanceStdFwk
{
using namespace SundanceUtils;
using namespace SundanceStdMesh;
using namespace SundanceStdMesh::Internal;
using namespace SundanceCore;
using namespace SundanceCore;

namespace Internal
{
using namespace Teuchos;

/** 
 * Grouper
 */
class TrivialGrouper : public GrouperBase
{
public:
  /** */
  TrivialGrouper() : GrouperBase() {;}

  /** */
  virtual ~TrivialGrouper(){;}

  /** */
  virtual void findGroups(const EquationSet& eqn,
    const CellType& maxCellType,
    int spatialDim,
    const CellType& cellType,
    int cellDim,
    const QuadratureFamily& quad,
    const RefCountPtr<SparsitySuperset>& sparsity,
    bool isInternalBdry,                              
    Array<RCP<IntegralGroup> >& groups) const ;
                              
};

}
}


#endif
